
# ___________________________________ #
#        Example Functions File       #
# ___________________________________ #
#
# Created:      13 April 2023
# Last Updated: 14 April 2023
#
# ~ writes functions to use in other files
#
# Brady Rippon
# ___________________________________ #


# load in packages
library(tidyverse)
library(gtsummary)

# create summary table for iris
iris_tbl <- function(data){
  
  # creates gtsummary table
  tbl <- tbl_summary(data, by = Species) %>% 
    add_overall() %>% 
    add_p() %>% bold_p(t = 0.1) %>% 
    bold_labels() %>% 
    modify_spanning_header(all_stat_cols() ~ "**Species**")
  
  return(tbl)
}

# changes output rendering of table
iris_tblClean <- function(tbl){
  
  tbl$table_body <- tbl$table_body %>% 
    mutate(
      row_type = ifelse(str_detect(variable, "Length|Width|Area"), "level", row_type),
      p.value = ifelse(str_detect(variable, "Length|Width|Area"), NA, p.value)
    )
  
  return(tbl)
}
 
# create figure
iris_figure <- function(data){
  sepal_plot <- data %>% ggplot(aes(x = Sepal.Width, y = Sepal.Length, 
                                    fill = Species, size = Sepal.Area)) +
    scale_fill_manual(values=c("#999999", "#E69F00", "#56B4E9")) +
    geom_point(shape = 21, color = "black") +
    xlab("Sepal Width (cm)") + ylab("Sepal Length (cm)") +
    guides(size = guide_legend(title = "Sepal Area")) +
    theme_bw() +
    theme(legend.position = "bottom",
          legend.direction = "vertical")
  
  
  petal_plot <- data %>% ggplot(aes(x = Petal.Width, y = Petal.Length, 
                                    fill = Species, size = Petal.Area)) +
    scale_fill_manual(values=c("#999999", "#E69F00", "#56B4E9")) +
    geom_point(shape = 21, color = "black") +
    xlab("Petal Width (cm)") + ylab("Petal Length (cm)") +
    guides(size = guide_legend(title = "Petal Area")) +
    theme_bw() +
    theme(legend.position = "bottom",
          legend.direction = "vertical")
  
  # combine plots
  iris_plot <- ggarrange(sepal_plot, petal_plot, nrow = 1, align = "h")
  
  return(iris_plot)
}
