
*_________________________________________________*
*												  *
*			   SAS MACRO DIRECTORY			      *
*			    WCM BIOSTATISTICS			      *
*				  BRADY RIPPON					  *
*												  *
*________________________ br77014@med.cornell.edu * 
*												  *

Created:      13 APR 2023
Last updated: 13 APR 2023



* -_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_ %size() _-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_- * ;

* Returns the number of oberservations in a dataset
*		Adapted from: Chris Swenson (NObs and NVars)
*		< http://sas.cswenson.com/categories/data-quality-macros > ;

%macro size(data, row=TRUE, col=TRUE);

%local arg dsid vid rc;

  * Open dataset;
	%let dsid=%sysfunc(open(&data));
		%let anobs=%sysfunc(attrn(&dsid, ANOBS));
		%let nRows=%sysfunc(attrn(&dsid, NOBS));
		%let nCols=%sysfunc(attrn(&dsid, NVars));
  * Close dataset;
	%let rc=%sysfunc(close(&dsid));

%if &row^=TRUE & &row^=FALSE %then %do;
	%put %str(E)RROR: %sysfunc(compbl(Toggle to include row count not properly specified.
									  Please select TRUE/FALSE for [row] option)).;
	%return;
%end;
%if &col^=TRUE & &col^=FALSE %then %do;
	%put %str(E)RROR: %sysfunc(compbl(Toggle to include column count not properly specified.
									  Please select TRUE/FALSE for [col] option)).;
	%return;
%end;

%if &col=FALSE %then %do;
	%put %str(N)OTE: %sysfunc(compbl(The dataset [&data] has &nRows rows)).;
	%goto done;
%end;

%if &row=FALSE %then %do;
	%put %str(N)OTE: %sysfunc(compbl(The dataset [&data] has &nCols columns)).;
	%goto done;
%end;

%put %str(N)OTE: %sysfunc(compbl(The dataset [&data] is &nRows x &nCols (&nRows rows and &nCols columns))).;
%done: ;

%mend size;

** EXAMPLE ** ;

/*
%size(SASHELP.iris);
*/

* This should return "The dataset [SASHELP.iris] is 150 x 5 (150 rows and 5 columns)" in SAS log;





* -_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_ %shuffle() _-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_- * ;

* Move variables to the front or back of a dataset (up to ten at a time);

%macro shuffle(datain, var1, var2, var3, var4, var5, var6, var7, var8, var9, var10, front=TRUE);

%if &front^=TRUE & &front^=FALSE %then %do;
	%put %str(E)RROR: %sysfunc(compbl(Direction to shuffle variable(s) not properly specified.
									  Please select TRUE/FALSE for [front] option)).;
	%return;
%end;

%if &front=TRUE %then %do;
	data &datain;
		retain &var1 &var2 &var3 &var4 &var5 &var6 &var7 &var8 &var9 &var10;
		set &datain;
	run;

	%put %str(N)OTE: %sysfunc(compbl(Specified variable(s) have been shuffled 
									 to the front of [&datain])).;
	%goto done;
%end;

%if &front=FALSE %then %do;
	data &datain;
		set &datain;
		match = _n_;
	data shuffle_temp1(drop=&var1 &var2 &var3 &var4 &var5 &var6 &var7 &var8 &var9 &var10);
		set &datain;
	data shuffle_temp2(keep=match &var1 &var2 &var3 &var4 &var5 &var6 &var7 &var8 &var9 &var10);
		set &datain;
	data &datain;
		merge shuffle_temp1 shuffle_temp2;
		by match;
		drop match;
	run;

	proc datasets library=work nolist;
   		delete shuffle_temp1 shuffle_temp2;
	quit; run;

	%put %str(N)OTE: %sysfunc(compbl(Specified variable(s) have been shuffled 
									 to the back of [&datain])).;
	%goto done; 
%end;

%done: ;
%mend shuffle;

** EXAMPLE ** ;

/* (#1)
data iris;
	set SASHELP.iris;
run;

%shuffle(iris, PetalLength);
*/

/* (#2)
data iris;
	set SASHELP.iris;
run;

%shuffle(iris, PetalLength, SepalLength, Species, front=FALSE);
*/

* Example 1: The variable [PetalLength] is now the first column in [iris]. Check working directory
  Example 2: [PetalLength], [SepalLength], and [Species] moved to back of [iris]. Check working directory; 
